@@ -6,6 +6,7 @@ pub mod block;
 pub mod check_connected;
 pub mod check_error;
 pub mod check_logic_loops;
+pub mod check_timing;
 pub mod clock;
 pub mod code_writer;
 pub mod constant;
@@ -23,6 +24,7 @@ pub mod signed;
 pub mod simulate;
 pub mod struct_valued;
 pub mod synth;
+pub mod timing;
 pub mod type_descriptor;
 pub mod vcd_probe;
 pub mod verilog_gen;
