@@ -1,4 +1,5 @@
 use crate::core::prelude::*;
+use crate::dff_setup;
 use crate::widgets::dff::DFF;
 
 #[derive(LogicBlock)]
@@ -6,6 +7,7 @@ pub struct EdgeDetector {
     pub input_signal: Signal<In, Bit>,
     pub edge_signal: Signal<Out, Bit>,
     pub clock: Signal<In, Clock>,
+    pub reset: Signal<In, Reset>,
     prev: DFF<Bit>,
     current: DFF<Bit>,
     is_rising: Constant<Bit>,
@@ -17,6 +19,7 @@ impl EdgeDetector {
             input_signal: Default::default(),
             edge_signal: Default::default(),
             clock: Default::default(),
+            reset: Default::default(),
             prev: Default::default(),
             current: Default::default(),
             is_rising: Constant::new(is_rising),
@@ -27,8 +30,7 @@ impl EdgeDetector {
 impl Logic for EdgeDetector {
     #[hdl_gen]
     fn update(&mut self) {
-        self.prev.clk.next = self.clock.val();
-        self.current.clk.next = self.clock.val();
+        dff_setup!(self, clock, reset, prev, current);
         self.prev.d.next = self.current.q.val();
         self.current.d.next = self.is_rising.val() ^ self.input_signal.val();
         self.edge_signal.next = !self.current.q.val() & self.prev.q.val();
@@ -40,6 +42,7 @@ fn test_edge_detector_synthesizes() {
     let mut uut = EdgeDetector::new(false);
     uut.input_signal.connect();
     uut.clock.connect();
+    uut.reset.connect();
     uut.connect_all();
     yosys_validate("edge", &generate_verilog(&uut)).unwrap();
 }
