@@ -138,6 +138,7 @@ impl Logic for I2CDriver {
                             self.state.d.next = State::Restart
                         }
                         I2CDriverCmd::Noop => {}
+                        _ => {}
                     }
                 }
             }
@@ -226,6 +227,9 @@ impl Logic for I2CDriver {
                     }
                 }
             }
+            _ => {
+                self.state.d.next = State::Idle;
+            }
         }
         if self.set_scl.val() {
             self.scl_flop.d.next = false;
