@@ -189,6 +189,9 @@ impl Logic for I2CTarget {
                     self.stop.next = true;
                 }
             }
+            _ => {
+                self.state.d.next = State::Idle;
+            }
         }
         if self.set_sda.val() {
             self.sda_flop.d.next = false;
