@@ -6,6 +6,8 @@ pub use crate::widgets::fifo::async_fifo::AsynchronousFIFO;
 //pub use crate::widgets::bidirectional_bus::{
 //    BidiBusD, BidiBusM, BidiMaster, BidiSimulatedDevice, FifoBus, FifoBusIn,
 //};
+pub use crate::dff_setup;
+pub use crate::widgets::auto_reset::AutoReset;
 pub use crate::widgets::delay_line::DelayLine;
 pub use crate::widgets::dff::DFF;
 pub use crate::widgets::edge_detector::EdgeDetector;
@@ -41,7 +43,6 @@ pub use crate::widgets::spi::master_dynamic_mode::{SPIConfigDynamicMode, SPIMast
 pub use crate::widgets::spi::mux::{MuxMasters, MuxSlaves};
 pub use crate::widgets::spi::slave::SPISlave;
 pub use crate::widgets::strobe::Strobe;
-pub use crate::widgets::sync_reset::SyncReset;
 pub use crate::widgets::synchronizer::{
     BitSynchronizer, SyncReceiver, SyncSender, VectorSynchronizer,
 };
