@@ -6,6 +6,7 @@ pub struct PulseWidthModulator<const N: usize> {
     pub enable: Signal<In, Bit>,
     pub threshold: Signal<In, Bits<N>>,
     pub clock: Signal<In, Clock>,
+    pub reset: Signal<In, Reset>,
     pub active: Signal<Out, Bit>,
     counter: DFF<Bits<N>>,
 }
@@ -16,6 +17,7 @@ impl<const N: usize> Default for PulseWidthModulator<N> {
             enable: Signal::default(),
             threshold: Signal::default(),
             clock: Signal::default(),
+            reset: Default::default(),
             active: Signal::new_with_default(false),
             counter: Default::default(),
         }
@@ -25,7 +27,7 @@ impl<const N: usize> Default for PulseWidthModulator<N> {
 impl<const N: usize> Logic for PulseWidthModulator<N> {
     #[hdl_gen]
     fn update(&mut self) {
-        self.counter.clk.next = self.clock.val();
+        clock_reset!(self, clock, reset, counter);
         self.counter.d.next = self.counter.q.val() + 1_u32;
         self.active.next = self.enable.val() & (self.counter.q.val() < self.threshold.val());
     }
